﻿namespace Phoenix.Main.Frame
{
    using System;
    using System.Reflection;
    using System.Windows.Forms;

    using Phoenix.Helpers.Misc;
    using Phoenix.Log.Writer;
    using Phoenix.Translation;
    using Phoenix.View;

    /// <summary>
    /// Contains the info about Phoenix Suite.
    /// </summary>
    partial class AboutBox : TranslatedForm
    {
        #region Constructors

        public AboutBox()
        {
            InitializeComponent();

            base.Logger = LogManager.GetLogger(typeof(AboutBox));

            this.labelProductName.Text = AssemblyProduct;
            this.labelVersion.Text = String.Format("Version {0}", AssemblyVersion);
            this.labelCopyright.Text = AssemblyCopyright;
            this.labelCompanyName.Text = "Written by: {0}".Translate(AssemblyCompany);
            this.textBoxDescription.Text = this.GetLicense();

            this.FillComponentVersion();
        }

        #endregion Constructors

        #region Properties

        public string AssemblyCompany
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCompanyAttribute), false);
                if (attributes.Length == 0)
                {
                    return string.Empty;
                }
                return ((AssemblyCompanyAttribute)attributes[0]).Company;
            }
        }

        public string AssemblyCopyright
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyCopyrightAttribute), false);
                if (attributes.Length == 0)
                {
                    return string.Empty;
                }
                return ((AssemblyCopyrightAttribute)attributes[0]).Copyright;
            }
        }

        public string AssemblyDescription
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyDescriptionAttribute), false);
                if (attributes.Length == 0)
                {
                    return string.Empty;
                }
                return ((AssemblyDescriptionAttribute)attributes[0]).Description;
            }
        }

        public string AssemblyProduct
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyProductAttribute), false);
                if (attributes.Length == 0)
                {
                    return string.Empty;
                }
                return ((AssemblyProductAttribute)attributes[0]).Product;
            }
        }

        public string AssemblyTitle
        {
            get
            {
                object[] attributes = Assembly.GetExecutingAssembly().GetCustomAttributes(typeof(AssemblyTitleAttribute), false);
                if (attributes.Length > 0)
                {
                    AssemblyTitleAttribute titleAttribute = (AssemblyTitleAttribute)attributes[0];
                    if (string.IsNullOrEmpty(titleAttribute.Title))
                    {
                        return titleAttribute.Title;
                    }
                }
                return System.IO.Path.GetFileNameWithoutExtension(Assembly.GetExecutingAssembly().CodeBase);
            }
        }

        public string AssemblyVersion
        {
            get
            {
                return Assembly.GetExecutingAssembly().GetName().Version.ToString();
            }
        }

        #endregion Properties

        #region Methods

        private void AboutBox_Load(object sender, EventArgs e)
        {
            this.Text = String.Format("About {0}", AssemblyTitle);
        }

        private void AddLvItem(string assemblyName)
        {
            try
            {
                Assembly asm = Assembly.Load(assemblyName);
                AssemblyName asmName = asm.GetName();
                ListViewItem item = new ListViewItem(asmName.Name);
                ListViewItem.ListViewSubItem subitem = new ListViewItem.ListViewSubItem(item, asmName.Version.ToString());
                item.SubItems.Add(subitem);
                lv_Components.Items.Add(item);
            }
            catch (Exception)
            {
                ListViewItem item = new ListViewItem(string.Format("'{0}' does not exist!", assemblyName));
                lv_Components.Items.Add(item);
            }
        }

        private void FillComponentVersion()
        {
            this.AddLvItem("Phoenix.Helpers");
            this.AddLvItem("Phoenix.Contracts");
            this.AddLvItem("Phoenix.Log");
            this.AddLvItem("Phoenix.Translation");
            this.AddLvItem("Phoenix.BLL");
            this.AddLvItem("Phoenix.Model");
            this.AddLvItem("Phoenix.View");
            this.AddLvItem("System.Data.SQLite");
            this.AddLvItem("WeifenLuo.WinFormsUI.Docking");
            this.AddLvItem("Ascend");
            this.AddLvItem("StructureMap");
        }

        private string GetLicense()
        {
            try
            {
                return EmbeddedResources.GetString(typeof(PhoenixMain), "Resources.License.txt");
            }
            catch (Exception ex)
            {
                base.Logger.Error(ex);
                return "License not found!";
            }
        }

        #endregion Methods
    }
}