﻿namespace Phoenix.Main
{
    using System;
    using System.Reflection;
    using System.Threading;
    using System.Windows.Forms;

    using log4net;

    using Phoenix.Helpers.Winforms;
    using Phoenix.Translation;
    using Phoenix.View.Frame;

    static class Program
    {
        #region Methods

        private static void Application_ThreadException(object sender, System.Threading.ThreadExceptionEventArgs e)
        {
            ILog logger = LogManager.GetLogger(typeof(Program));
            logger.Fatal(e.Exception.Message, e.Exception);
            MessageBoxes.Error("An unexpected error occured: {0}{1}{0} For more information, check the logs!"
                    .Translate(Environment.NewLine, e.Exception.Message));
        }

        /// <summary>
        /// The main entry point for the application.
        /// </summary>
        [STAThread]
        static void Main()
        {
            Thread.CurrentThread.Name = "nDoctor main thread";
            Application.EnableVisualStyles();
            Application.SetCompatibleTextRenderingDefault(false);
            Application.ThreadException += Application_ThreadException;

            //Logger
            Assembly.Load("Phoenix.Helpers.Winforms");
            ILog logger = LogManager.GetLogger(typeof(Program));

            logger.Info("Initialisation of Phoenix.");

            var mainForm = new PhoenixMain();
            Splash.ShowSplash(mainForm);

            if (Splash.Succeeded)
            {
                logger.Info("Phoenix Suite is starting.");
                Application.Run(mainForm);
                logger.Info("Phoenix Suite has closed");
            }
        }

        #endregion Methods
    }
}