﻿namespace Phoenix.Model.Bll.Domain
{
    using System.ComponentModel;

    /// <summary>
    /// Root for a Plain Old CLR Object
    /// </summary>
    public class Poco : INotifyPropertyChanged
    {
        #region Fields

        protected long m_ID = -1;

        #endregion Fields

        #region Events

        /// <summary>
        /// Occurs when a property value changes.
        /// </summary>
        public virtual event PropertyChangedEventHandler PropertyChanged;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets the ID of this tuple.
        /// </summary>
        /// <value>The ID.</value>
        public virtual long ID
        {
            get
            {
                return this.m_ID;
            }
            protected set
            {
                this.Set(this, "ID", ref m_ID, value);
            }
        }

        /// <summary>
        /// Gets a value indicating whether this instance is empty.
        /// </summary>
        /// <value><c>true</c> if this instance is empty; otherwise, <c>false</c>.</value>
        public virtual bool IsEmpty
        {
            get
            {
                return (this.m_ID < 0);
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets the specified new value into the old value and notify change
        /// if value changed.
        /// </summary>
        /// <typeparam name="T">Generic type</typeparam>
        /// <param name="sender">The sender.</param>
        /// <param name="propertyName">Name of the property.</param>
        /// <param name="oldValue">The old value.</param>
        /// <param name="newValue">The new value.</param>
        protected virtual void Set<T>(object sender, string propertyName, ref T oldValue, T newValue)
        {
            if (Equals(newValue, oldValue)) return;

            oldValue = newValue;
            this.OnPropertyChanged(propertyName);
        }

        private void OnPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion Methods
    }
}