﻿namespace Phoenix.Model.Management
{
    using System;

    using Phoenix.Contracts;
    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal;
    using Phoenix.Presenter.Interfaces;

    /// <summary>
    /// Provide a manager to delete patient from the repositories.
    /// </summary>    
    public class PatientDeleterModel : Manager<Patient>
    {
        #region Fields

        IDeleter<Patient> view;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PatientDeleterModel"/> class.
        /// </summary>
        /// <param name="view">The view.</param>
        public PatientDeleterModel(IDeleter<Patient> view)
            : base(RepositoryFactory.Get<IPatientRepository>())
        {
            this.view = view;
            this.view.Deleted += new EventHandler<EventArgs<Patient>>(view_ItemDeleted);
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns><c>True</c> if the data have passed the validation;
        /// otherwise <c>False</c></returns>
        public override bool ValidateData()
        {
            throw new NotImplementedException();
        }

        private void view_ItemDeleted(object sender, EventArgs<Patient> e)
        {
            IPatientRepository repository = base.Repository as IPatientRepository;
            Assert.IsTrue((repository != null), string.Format(
                "The repository should be of type 'IPatientRepository but is of type {0}'", base.Repository.GetType().Name));

            repository.ClearFromRepository(e.Data);
            base.Delete(e.Data);
        }

        #endregion Methods
    }
}