﻿namespace Phoenix.Model.Dal.Configuration
{
    using System;
    using System.Diagnostics;

    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Dal.Repositories;

    using StructureMap;

    /// <summary>
    /// Gives an instance of a repository. This class allows
    /// low dependency on the ORM.
    /// </summary>
    public static class Repositories
    {
        #region Properties

        private static bool IsLoaded
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Gets the right instance for the specified type.
        /// </summary>
        /// <typeparam name="T">The type of the instance to return that fits the specified interface.</typeparam>
        /// <returns>The right instance related to the specified interface</returns>
        [DebuggerStepThrough]
        public static T Get<T>()
        {
            try
            {
                if (!IsLoaded)
                    Load();
                return ObjectFactory.GetInstance<T>();
            }
            catch (Exception ex)
            {
                string msg = string.Format("Impossible to find an instance for this interface '{0}'", typeof(T));
                throw new InvalidOperationException(msg, ex);
            }
        }

        private static void Load()
        {
            ObjectFactory.Configure(e =>
                {
                    e.For<IPatientRepository>().Use<PatientRepository>();
                    e.For<IInsuranceRepository>().Use<InsuranceRepository>();
                    e.For<IDoctorTypeRepository>().Use<DoctorTypeRepository>();
                    e.For<IDoctorRepository>().Use<DoctorRepository>();
                    e.For<IPracticeRepository>().Use<PracticeRepository>();
                    e.For<IReputationRepository>().Use<ReputationRepository>();
                    e.For<IBmiRepository>().Use<BmiRepository>();
                    e.For<IRelationTypeRepository>().Use<RelationTypeRepository>();
                    e.For<IKeywordGroupRepository>().Use<KeywordGroupRepository>();
                    e.For<IMacroRepository>().Use<MacroRepository>();
                    e.For<IMedicalCardRepository>().Use<MedicalCardRepository>();
                    e.For<IMedicalCardTypeRepository>().Use<MedicalCardTypeRepository>();
                    e.For<IRelationRepository>().Use<RelationRepository>();

                });

            IsLoaded = true;
        }

        #endregion Methods
    }
}