﻿namespace Phoenix.Model.Dal.Repositories
{
    using System;
    using System.Collections.Generic;
    using System.Linq;

    using NHibernate;
    using NHibernate.Linq;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Provides CRUD features for a doctor.
    /// </summary>
    public class DoctorRepository : Repository<Doctor>, IDoctorRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DoctorRepository"/> class.
        /// </summary>
        public DoctorRepository()
            : base("Doctor", "LastName")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(Doctor item)
        {
            return (from Patient p in this.Session.Linq<Patient>()
                    where p.Doctors.Contains(item)
                    select p).Count() > 0;
        }

        /// <summary>
        /// Searches the items in the database that respect the specified criterion.
        /// Every not empty properties are considered as criterion for the search.
        /// Every empty (null or with default values) are excluded of the search.
        /// The search is optimistic on text. For instance, that'll search on all
        /// the tuples that contains the text and not that has exactly the specified name.
        /// </summary>
        /// <param name="criterion">The criterion.</param>
        /// <returns>
        /// A list of the items that respect the criterion.
        /// </returns>
        //TODO Replace this method by a new one more staight forward
        [Obsolete("Replace this method by a new one more staight forward")]
        public IList<Doctor> Search(Doctor criterion)
        {
            if (criterion.LastName == "*")
                return base.GetAllRows(OrderBy.ASC);
            else
                return this.RegularSearch(criterion);
        }

        private IList<Doctor> RegularSearch(Doctor criterion)
        {
            Assert.IsNotNull(criterion, "criterion");

            string hql = "FROM Doctor p WHERE p.LastName LIKE :LastName AND p.FirstName LIKE :FirstName";

            string firstName = (!string.IsNullOrEmpty(criterion.FirstName))
                                   ? criterion.FirstName
                                   : string.Empty;

            string lastName = (!string.IsNullOrEmpty(criterion.LastName))
                                  ? criterion.LastName
                                  : string.Empty;

            if (criterion.Specialisation != null && !criterion.Specialisation.IsEmpty)
            {
                hql += " AND p.Specialisation = :DoctorType";
            }

            hql += " ORDER BY p.LastName";

            IQuery query = this.Session.CreateQuery(hql);
            query.SetParameter("FirstName", firstName + "%");
            query.SetParameter("LastName", lastName.ToUpper() + "%");
            if (criterion.Specialisation != null && !criterion.Specialisation.IsEmpty)
            {
                query.SetParameter("DoctorType", criterion.Specialisation);
            }

            return query.List<Doctor>();
        }

        #endregion Methods
    }
}