﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Collections.Generic;
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Manage a doctor type.
    /// </summary>
    public class DoctorTypeRepository : Repository<DoctorType>, IDoctorTypeRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DoctorTypeRepository"/> class.
        /// </summary>
        public DoctorTypeRepository()
            : base("DoctorType", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(DoctorType item)
        {
            return (from Doctor d in this.Session.Linq<Doctor>()
                    where d.Specialisation == item
                    select d).Count() > 0;
        }

        /// <summary>
        /// Searches the items in the database that respect the specified criterion.
        /// Every not empty properties are considered as criterion for the search.
        /// Every empty (null or with default values) are excluded of the search.
        /// The search is optimistic on text. For instance, that'll search on all
        /// the tuples that contains the text and not that has exactly the specified name.
        /// </summary>
        /// <param name="criterion">The criterion.</param>
        /// <returns>
        /// A list of the items that respect the criterion.
        /// </returns>
        public IList<DoctorType> Search(DoctorType criterion)
        {
            Assert.IsTrue((criterion != null), "The criterion of the search can't be null!");

            return (from DoctorType d in this.Session.Linq<DoctorType>()
                    where d == criterion
                    select d).ToList();
        }

        #endregion Methods
    }
}