﻿namespace Phoenix.Model.Dal.Repositories
{
    using System.Linq;

    using NHibernate.Linq;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;

    /// <summary>
    /// Repository to store Drug types
    /// </summary>
    public class DrugTypeRepository : Repository<DrugType>, IDrugTypeRepository
    {
        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="DrugRepository"/> class.
        /// </summary>
        public DrugTypeRepository()
            : base("DrugType", "Title")
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Determines whether the specified item is referenced.
        /// </summary>
        /// <param name="item">The item.</param>
        /// <returns>
        /// 	<c>true</c> if the specified item is referenced; otherwise, <c>false</c>.
        /// </returns>
        public override bool IsReferenced(DrugType item)
        {
            return (from Drug d in this.Session.Linq<Drug>()
                    where d.Type == item
                    select d).Count() > 0;
        }

        #endregion Methods
    }
}