﻿namespace Phoenix.Presenter.Interfaces
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Helpers.Misc;
    using Phoenix.Model.Bll.Domain;

    public interface ICalendarPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when user ask to display meetings in the specified range of time.
        /// </summary>
        event EventHandler<EventArgs<DateTime, DateTime>> Displaying;

        /// <summary>
        /// Occurs when a meeting is deleted.
        /// </summary>
        event EventHandler<EventArgs<Meeting>> MeetingDeleted;

        /// <summary>
        /// Occurs when a personal meeting is updated.
        /// </summary>
        event EventHandler<EventArgs<Meeting>> MeetingUpdated;

        /// <summary>
        /// Occurs when meetings are updated.
        /// </summary>
        event EventHandler<EventArgs<Patient>> Updated;

        #endregion Events

        #region Methods

        /// <summary>
        /// Displays the specified meetings.
        /// </summary>
        /// <param name="workMeetings">The work meetings.</param>
        /// <param name="meetings">The meetings.</param>
        void Display(IList<WorkMeeting> workMeetings, IList<Meeting> meetings);

        #endregion Methods
    }
}