﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    /// <summary>
    /// Indicates what validation failed.
    /// </summary>
    public enum DoctorFailOn
    {
        /// <summary>
        /// The last name is a number.
        /// </summary>
        LastNameIsNum,
        /// <summary>
        /// The last name is empty.
        /// </summary>
        LastNameIsEmpty,
        /// <summary>
        /// The first name is a number.
        /// </summary>
        FirstNameIsNum,
        /// <summary>
        /// The first name is empty.
        /// </summary>
        FirstNameIsEmpty,
        /// <summary>
        /// The email is not valid.
        /// </summary>
        EmailIsNotValid,
        /// <summary>
        /// The profesional phone number is not valid.
        /// </summary>
        ProPhoneIsNotValid,
        /// <summary>
        /// The profesional mobile phone number is not valid.
        /// </summary>
        ProMobileIsNotValid,
        /// <summary>
        /// The street is a number.
        /// </summary>
        StreetIsNum,
        /// <summary>
        /// The city is a number.
        /// </summary>
        CityIsNum,
        /// <summary>
        /// The doctor does not have specialisation.
        /// </summary>
        NoSpecialisation,
        /// <summary>
        /// This item is referenced somewhere else in the domain
        /// </summary>
        Referenced,
    }

    #endregion Enumerations

    /// <summary>
    /// Provides a view to manage a doctor.
    /// </summary>
    public interface IDoctorInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when a doctor isdeleted.
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when doctor is inserted.
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when the view is loading.
        /// </summary>        
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when a doctor is updated.
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        Doctor ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the specialisations.
        /// </summary>
        /// <value>The specialisations.</value>
        List<DoctorType> Specialisations
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears previous error on validation failed.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Closes this instance when work is finished.
        /// </summary>
        void Close();

        /// <summary>
        /// Sets an error message to explain why data validation failed.
        /// </summary>
        /// <param name="failed">The fail.</param>
        /// <param name="message">The message.</param>
        void SetError(DoctorFailOn failed, string message);

        #endregion Methods
    }
}