﻿namespace Phoenix.Presenter.Interfaces.Input
{
    using System;
    using System.Collections.Generic;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Presenter.Helpers;

    #region Enumerations

    /// <summary>
    /// Indicate the reason why the validation failed
    /// </summary>
    public enum DrugFailedOn
    {
        /// <summary>
        /// The drug doesn't have any type
        /// </summary>
        NoType,
        /// <summary>
        /// The drug doesn't have any name
        /// </summary>
        NoName,
        /// <summary>
        /// This item is referenced somewhere else in the domain
        /// </summary>
        Referenced,
    }

    #endregion Enumerations

    /// <summary>
    ///  Provides feature for a GUI to manage drugs
    /// </summary>
    public interface IDrugInputPresenter
    {
        #region Events

        /// <summary>
        /// Occurs when user asked to delete an Drug
        /// </summary>
        event EventHandler Deleted;

        /// <summary>
        /// Occurs when user asked to insert an Drug
        /// </summary>
        event EventHandler Inserted;

        /// <summary>
        /// Occurs when the gui should be refreshed.
        /// </summary>
        event EventHandler Refreshed;

        /// <summary>
        /// Occurs when user asked to update an Drug
        /// </summary>
        event EventHandler Updated;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        Drug ItemToManage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the types of drug.
        /// </summary>
        /// <value>The types.</value>
        List<DrugType> Types
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the usage of this GUI item.
        /// Should be Insert, Update or Delete.
        /// </summary>
        /// <value>The usage.</value>
        Usage Usage
        {
            get;
            set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Clears previous error on validation failed.
        /// </summary>
        void ClearError();

        /// <summary>
        /// Sets an error message on validation failed.
        /// </summary>
        /// <param name="fail">Indicates where the validation failed.</param>
        /// <param name="message">The message to display.</param>
        void SetError(DrugFailedOn fail, string message);

        #endregion Methods
    }
}