﻿namespace Phoenix.Test.MedicalCardRelease
{
    using System;

    using NUnit.Framework;

    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Bll.Interface;
    using Phoenix.Model.Management;
    using Phoenix.Presenter.Interfaces.Manager;

    using Rhino.Mocks;
    using Rhino.Mocks.Interfaces;

    [TestFixture]
    public class MedicalCardTypeTestSuite : TestSuite
    {
        #region Methods

        [Test]
        public void CanRaiseEvent()
        {
            #region Setup
            IEventRaiser raiseDelete, raiseAdd, raiseUpdate;
            IRepository<MedicalCardType> repository = this.Mocks.DynamicMock<IRepository<MedicalCardType>>();
            IMedicalCardTypeManagerPresenter view = this.Mocks.DynamicMock<IMedicalCardTypeManagerPresenter>();
            MedicalCardTypeModel presenter = new MedicalCardTypeModel(view, repository);

            MedicalCardType validItem = new MedicalCardType()
            {
                Remark = "Some Remark",
                Title = "Some title",
            };
            #endregion

            using (this.Mocks.Record())
            {
                SetupResult.For(view.ItemToManage).Return(validItem);
                this.EventCounter = 0;

                view.Inserted += (sender, e) =>
                {
                    EventCounter++;
                };
                raiseAdd = LastCall.IgnoreArguments().GetEventRaiser();

                view.Deleted += (sender, e) =>
                {
                    EventCounter++;
                };
                raiseDelete = LastCall.IgnoreArguments().GetEventRaiser();

                view.Updated += (sender, e) =>
                {
                    EventCounter++;
                };
                raiseUpdate = LastCall.IgnoreArguments().GetEventRaiser();
            }
            raiseAdd.Raise(this, EventArgs.Empty);
            raiseDelete.Raise(this, EventArgs.Empty);
            raiseUpdate.Raise(this, EventArgs.Empty);

            Assert.AreEqual(3, EventCounter, string.Format(
                "Events ware fired '{0}' times but 3 times was expected!",
                EventCounter));
        }

        [Test]
        public void OnInvalidData()
        {
            #region Setup
            IRepository<MedicalCardType> repository = this.Mocks.DynamicMock<IRepository<MedicalCardType>>();
            IMedicalCardTypeManagerPresenter view = this.Mocks.DynamicMock<IMedicalCardTypeManagerPresenter>();

            MedicalCardTypeModel presenter = new MedicalCardTypeModel(view, repository);
            MedicalCardType invalidItem = new MedicalCardType()
            {
                Remark = string.Empty,
                Title = string.Empty,
            };
            #endregion

            using (this.Mocks.Record())
            {
                SetupResult.For(view.ItemToManage).Return(invalidItem);
            }

            bool result = presenter.ValidateData();
            Assert.AreEqual(false, result, "The validation should fail");
        }

        [Test]
        public void OnValidData()
        {
            #region Setup
            IRepository<MedicalCardType> repository = this.Mocks.DynamicMock<IRepository<MedicalCardType>>();
            IMedicalCardTypeManagerPresenter view = this.Mocks.DynamicMock<IMedicalCardTypeManagerPresenter>();

            MedicalCardTypeModel presenter = new MedicalCardTypeModel(view, repository);
            MedicalCardType validItem = new MedicalCardType()
            {
                Remark = "Some Remark",
                Title = "Some title",
            };
            #endregion

            using (this.Mocks.Record())
            {
                SetupResult.For(view.ItemToManage).Return(validItem);
            }

            bool result = presenter.ValidateData();
            Assert.AreEqual(true, result, "The validation should succeed");
        }

        #endregion Methods
    }
}