﻿namespace Phoenix.View.Helpers
{
    using System;

    using Phoenix.Helpers.Misc;
    using Phoenix.Translation;
    using Phoenix.View;

    /// <summary>
    /// Captchabox to ask confirmation from the user before executing anything.
    /// </summary>
    public partial class CaptchaBox : TranslateableForm
    {
        #region Fields

        private string explanation = "Before further processing, please confirm by writing the 4 digits code you can read below!";
        private Random random = new Random((int)DateTime.Now.Ticks);

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="CaptchaBox"/> class.
        /// </summary>
        public CaptchaBox()
        {
            InitializeComponent();
            this.TranslateForm();

            explanation = explanation.Translate();
            this.lbl_Explanation.Text = explanation;
        }

        #endregion Constructors

        #region Events

        /// <summary>
        /// Occurs when the confirmation failed.
        /// </summary>
        public event EventHandler ConfirmationFailed;

        /// <summary>
        /// Occurs when the confirmation succeeded.
        /// </summary>
        public event EventHandler ConfirmationSucceeded;

        #endregion Events

        #region Properties

        /// <summary>
        /// Gets or sets the explanation to provide to the captcha.
        /// </summary>
        /// <value>The explanation.</value>
        public string Explanation
        {
            get { return this.lbl_Explanation.Text; }
            set { this.lbl_Explanation.Text = value.Translate(); }
        }

        #endregion Properties

        #region Methods

        private void btn_OK_Click(object sender, EventArgs e)
        {
            string input = tb_CaptchaInput.Text;
            string captcha = lbl_CaptchaOutput.Text;

            if (input == captcha)
            {
                this.ConfirmationSucceeded.Raise(this);
                this.Close();
            }
            else
            {
                this.ConfirmationFailed.Raise(this);
                this.ResetCaptcha();
            }
        }

        private void CaptchaBox_Load(object sender, EventArgs e)
        {
            ResetCaptcha();
        }

        private void ResetCaptcha()
        {
            //Choose the random captcha code
            this.lbl_CaptchaOutput.Text = this.random.Next(1000, 9999).ToString();
        }

        #endregion Methods
    }
}