﻿namespace Phoenix.View.Input
{
    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Management;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.Translation;
    using Phoenix.View.Helpers;

    /// <summary>
    /// Manage <see cref="PathologyType"/>
    /// </summary>
    public class PathologyTypeInput : BasicInput, IPathologyTypeInputPresenter
    {
        #region Fields

        private const string VALUE1 = "Title";
        private const string VALUE2 = "Remark";

        private PathologyTypeModel presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PathologyTypeInput"/> class.
        /// </summary>
        public PathologyTypeInput()
            : base(new PathologyType(), VALUE1, VALUE2)
        {
            this.presenter = new PathologyTypeModel(this);
            this.Title = "Manage pathology type".Translate();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets yhe item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        public PathologyType ItemToManage
        {
            get { return base.Item as PathologyType; }
            set
            {
                var temp = value as PathologyType;
                this.Bind(temp, VALUE1, VALUE2);
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on validation failed.
        /// </summary>
        /// <param name="fail">Indicates where the validation failed.</param>
        /// <param name="message">The message to display.</param>
        public void SetError(PathologyTypeFailedOn fail, string message)
        {
            switch (fail)
            {
                case PathologyTypeFailedOn.NoName:
                    this.SetError(On.Value1, message);
                    break;
                case PathologyTypeFailedOn.Referenced:
                    PredifinedMsgBoxes.WarnOnReferencedItem();
                    break;
                default:
                    Assert.FailsOnEnumeration(fail);
                    break;
            }
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns>
        /// Returns <c>true</c> if the data is valid; otherwise <b>false</b>
        /// </returns>
        protected override bool ValidateData()
        {
            return this.presenter.ValidateData();
        }

        #endregion Methods
    }
}