﻿namespace Phoenix.View.Input
{
    using System;
    using System.Windows.Forms;

    using Phoenix.Helpers.Winforms;
    using Phoenix.Model.Bll.Domain;

    /// <summary>
    /// Inputs a meeting
    /// </summary>
    public partial class PatientMeetingInput : Form
    {
        #region Fields

        private WorkMeeting meeting;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="PatientMeetingInput"/> class.
        /// </summary>
        public PatientMeetingInput()
        {
            this.Size = this.MinimumSize;
            InitializeComponent();

            this.tdtp_EndDate.Value
                = this.tdtp_EndDate.Value.AddMinutes(30);
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the meeting.
        /// </summary>
        /// <value>The meeting.</value>
        public WorkMeeting Meeting
        {
            get
            {
                if (meeting == null) meeting = new WorkMeeting();
                meeting.Patient.FirstName = this.ttb_FirstName.Value;
                meeting.Patient.LastName = this.ttb_LastName.Value;
                meeting.StartDate = this.tdtp_StartDate.Value;
                meeting.EndDate = this.tdtp_EndDate.Value;
                meeting.Remark = this.tmt_Remarks.Value;
                meeting.Title = this.GetTitle(meeting);
                return this.meeting;
            }
            set
            {
                this.meeting = value;

                this.ttb_FirstName.Value = meeting.Patient.FirstName;
                this.ttb_LastName.Value = meeting.Patient.LastName;
                if (!value.IsEmpty)
                {
                    this.tdtp_StartDate.Value = meeting.StartDate; ;
                    this.tdtp_EndDate.Value = meeting.EndDate;
                }
                else
                {
                    this.tdtp_StartDate.Value = DateTime.Now;
                    this.tdtp_EndDate.Value = DateTime.Now.AddMinutes(30);
                }
                this.tmt_Remarks.Value = meeting.Remark;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets the time interval for the meeting.
        /// </summary>
        /// <param name="start">The start.</param>
        /// <param name="end">The end.</param>
        public void SetTimeInterval(DateTime start, DateTime end)
        {
            this.tdtp_StartDate.Value = start;
            this.tdtp_EndDate.Value = end;
        }

        private void btn_OK_Click(object sender, EventArgs e)
        {
            this.DialogResult = DialogResult.OK;
        }

        private string GetTitle(WorkMeeting meeting)
        {
            return string.Format("{0} {1}", meeting.Patient.FirstName, meeting.Patient.LastName.ToUpper());
        }

        private void MeetingInput_FormClosing(object sender, FormClosingEventArgs e)
        {
            if (this.DialogResult == DialogResult.Cancel) return;

            if (this.tdtp_EndDate.Value <= this.tdtp_StartDate.Value)
            {
                MessageBoxes.Asterisk("The begin of a meeting should be before the end!");
                e.Cancel = true;
            }
        }

        #endregion Methods
    }
}