﻿namespace Phoenix.View.Input
{
    using Phoenix.Contracts;
    using Phoenix.Model.Bll.Domain;
    using Phoenix.Model.Management;
    using Phoenix.Presenter.Interfaces.Input;
    using Phoenix.Translation;
    using Phoenix.View.Helpers;

    /// <summary>
    /// Manage the reputations
    /// </summary>
    public class ReputationInput : BasicInput, IReputationInputPresenter
    {
        #region Fields

        private const string VALUE1 = "Title";
        private const string VALUE2 = "Remark";

        private ReputationModel presenter;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ReputationInput"/> class.
        /// </summary>
        public ReputationInput()
            : base(new Reputation(), VALUE1, VALUE2)
        {
            this.presenter = new ReputationModel(this);
            this.Title = "Manage reputation".Translate();
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the item to manage.
        /// </summary>
        /// <value>The item to manage.</value>
        public Reputation ItemToManage
        {
            get { return base.Item as Reputation; }
            set
            {
                var temp = value as Reputation;
                this.Bind(temp, VALUE1, VALUE2);
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Sets an error message on validation failed.
        /// </summary>
        /// <param name="fail">Indicates where the validation failed.</param>
        /// <param name="message">The message to display.</param>
        public void SetError(ReputationFailedOn fail, string message)
        {
            switch (fail)
            {
                case ReputationFailedOn.EmptyTitle:
                    this.SetError(On.Value1, message);
                    break;
                case ReputationFailedOn.Referenced:
                    PredifinedMsgBoxes.WarnOnReferencedItem();
                    break;
                default:
                    Assert.FailsOnEnumeration(fail);
                    break;
            }
        }

        /// <summary>
        /// Validates the data.
        /// </summary>
        /// <returns>
        /// Returns <c>true</c> if the data is valid; otherwise <b>false</b>
        /// </returns>
        protected override bool ValidateData()
        {
            return this.presenter.ValidateData();
        }

        #endregion Methods
    }
}