﻿namespace Phoenix.Presenter.Search.Criterion
{
    using System.ComponentModel;
    using System.Windows.Forms;

    /// <summary>
    /// Provides an input for numeric criterion.
    /// </summary>
    public class NumericCriterion : CriterionControl, ICriterionControl
    {
        #region Fields

        private NumericUpDown nud_Numeric = new NumericUpDown();

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="NumericCriterion"/> class.
        /// </summary>
        public NumericCriterion()
        {
            base.AddInCriterionControl(this.nud_Numeric);
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets the criterion's number.
        /// </summary>
        /// <value></value>
        /// <number>The criterion's number.</number>
        [Browsable(false)]
        public override object Value
        {
            get
            {
                return this.nud_Numeric.Value;
            }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Checks the values the user entered and provides
        /// warning message if values are not correct.
        /// </summary>
        /// <returns>
        /// 	<c>True</c> if the check succeed. Otherwise <c>False</c>.
        /// </returns>
        public override bool ValidateCriterions()
        {
            return true;
        }

        /// <summary>
        /// Clears the value of the criterion.
        /// </summary>
        protected override void ClearValue()
        {
            this.nud_Numeric.Value = 0;
        }

        #endregion Methods
    }
}