﻿namespace Phoenix.Helpers.Winforms.Controls
{
    using System.Collections.Generic;

    /// <summary>
    /// Get a ComboBox item ready for binding.
    /// </summary>
    public class ComboBoxItem
    {
        #region Fields

        private string display;
        private object value;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Initializes a new instance of the <see cref="ComboBoxItem"/> class.
        /// </summary>
        /// <param name="display">The display.</param>
        /// <param name="value">The value.</param>
        public ComboBoxItem(string display, object value)
        {
            this.display = display;
            this.value = value;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the display member.
        /// </summary>
        /// <value>The display.</value>
        public string Display
        {
            set { display = value; }
            get { return display; }
        }

        /// <summary>
        /// Gets or sets the value.
        /// </summary>
        /// <value>The value.</value>
        public object Value
        {
            set { this.Value = value; }
            get { return value; }
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Gets the data source.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="list">The list.</param>
        /// <param name="displayMember">The display member.</param>
        /// <returns></returns>
        public static List<ComboBoxItem> GetDataSource<T>(IList<T> list, string displayMember)
        {
            List<ComboBoxItem> result = new List<ComboBoxItem>();
            foreach (var item in list)
            {
                result.Add(new ComboBoxItem(GetDisplay(item, displayMember), item));
            }
            return result;
        }

        private static string GetDisplay(object instance, string property)
        {
            var value = instance.GetType().GetProperty(property).GetValue(instance, null);
            return value as string;
        }

        #endregion Methods
    }
}