﻿namespace Phoenix.Helpers.Winforms
{
    using System.Windows.Forms;

    /// <summary>
    /// Provides preformated translated MessageBoxes
    /// </summary>
    public static class MessageBoxes
    {
        #region Methods

        /// <summary>
        /// Asterisk message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Asterisk(object message)
        {
            var icon = MessageBoxIcon.Asterisk;
            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// Error message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Error(object message)
        {
            var icon = MessageBoxIcon.Error;
            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// Exclamation message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Exclamation(object message)
        {
            var icon = MessageBoxIcon.Exclamation;
            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// Hand message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Hand(object message)
        {
            var icon = MessageBoxIcon.Hand;

            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// Information message box.
        /// </summary>
        /// <param name="format">A composite format string.</param>
        /// <param name="args">An <see cref="System.Object"/> array containing zero or more objects to format.</param>
        public static void Information(object format, params object[] args)
        {
            string message = string.Format(format.ToString(), args);
            var icon = MessageBoxIcon.Information;

            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// None message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void None(object message)
        {
            var icon = MessageBoxIcon.None;
            MessageBox.Show(message.ToString()
                , "Message"
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// None message box.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="title">The title which won't be translated).</param>
        public static void None(object message, object title)
        {
            MessageBox.Show(message.ToString(), title.ToString(), MessageBoxButtons.OK, MessageBoxIcon.None);
        }

        /// <summary>
        /// Question message box.
        /// </summary>
        /// <param name="message">The message.</param>
        /// <param name="messageBoxButton">The message box button.</param>
        public static DialogResult Question(object message, MessageBoxButtons messageBoxButton)
        {
            var icon = MessageBoxIcon.Question;
            return MessageBox.Show(message.ToString()
                , icon.ToString()
                , messageBoxButton
                , icon);
        }

        /// <summary>
        /// Question message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static DialogResult Question(object message)
        {
            return MessageBoxes.Question(message.ToString(), MessageBoxButtons.YesNo);
        }

        /// <summary>
        /// Stop message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Stop(object message)
        {
            var icon = MessageBoxIcon.Stop;
            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        /// <summary>
        /// Warning message box.
        /// </summary>
        /// <param name="message">The message.</param>
        public static void Warning(object message)
        {
            var icon = MessageBoxIcon.Warning;
            MessageBox.Show(message.ToString()
                , icon.ToString()
                , MessageBoxButtons.OK
                , icon);
        }

        #endregion Methods
    }
}