﻿namespace Phoenix.Helpers.Misc
{
    using System;
    using System.Diagnostics;

    /// <summary>
    /// Provides helper extention for events
    /// </summary>
    public static class EventExtension
    {
        #region Methods

        /// <summary>
        /// Raises this event with the specified eventargs.
        /// </summary>
        /// <param name="eventHandler">The event handler.</param>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        [DebuggerStepThrough]
        public static void Raise(this EventHandler eventHandler, object sender, EventArgs e)
        {
            EventHandler handler = eventHandler;
            if (handler != null)
            {
                eventHandler(sender, e);
            }
        }

        /// <summary>
        /// Raises this event with empty EventArgs.
        /// </summary>
        /// <param name="eventHandler">The event handler.</param>
        /// <param name="sender">The sender.</param>
        [DebuggerStepThrough]
        public static void Raise(this EventHandler eventHandler, object sender)
        {
            EventHandler handler = eventHandler;
            if (handler != null)
            {
                eventHandler(sender, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Raises this event with empty EventArgs.
        /// </summary>
        /// <param name="eventHandler">The event handler.</param>
        /// <param name="sender">The sender.</param>
        [DebuggerStepThrough]
        public static void Raise(this EventHandler<EventArgs> eventHandler, object sender)
        {
            EventHandler<EventArgs> handler = eventHandler;
            if (handler != null)
            {
                eventHandler(sender, EventArgs.Empty);
            }
        }

        /// <summary>
        /// Raises this event with the specified eventargs.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <param name="eventHandler">The event handler.</param>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The e.</param>
        [DebuggerStepThrough]
        public static void Raise<T>(this EventHandler<T> eventHandler, object sender, T e)
            where T : EventArgs
        {
            EventHandler<T> handler = eventHandler;
            if (handler != null)
            {
                eventHandler(sender, e);
            }
        }

        #endregion Methods
    }

    /// <summary>
    /// Provides helpers extension for nullity checks
    /// </summary>
    public static class NullExtension
    {
        #region Methods

        /// <summary>
        /// Determines whether this object is not null.
        /// </summary>
        /// <param name="source">The source.</param>
        /// <returns>
        /// 	<c>true</c> if the specified source is not null; otherwise, <c>false</c>.
        /// </returns>        
        [DebuggerStepThrough]
        public static bool IsNotNull(this object source)
        {
            return (source != null);
        }

        /// <summary>
        /// Determines whether this object is null.
        /// </summary>
        /// <param name="source">The source.</param>
        /// <returns>
        /// 	<c>true</c> if the specified source is null; otherwise, <c>false</c>.
        /// </returns>
        [DebuggerStepThrough]
        public static bool IsNull(this object source)
        {
            return (source == null);
        }

        #endregion Methods
    }

    /// <summary>
    /// Provides helper methods for strings.
    /// </summary>
    public static class StringExtension
    {
        #region Methods

        /// <summary>
        /// Determines whether the specified text is number.
        /// </summary>
        /// <param name="text">The text.</param>
        /// <returns>
        /// 	<c>true</c> if the specified text is number; otherwise, <c>false</c>.
        /// </returns>
        [DebuggerStepThrough]
        public static bool IsNumeric(this string text)
        {
            float value;
            return float.TryParse(text, out value);
        }

        #endregion Methods
    }
}