﻿namespace Phoenix.Helpers.Misc
{
    using System;
    using System.IO;
    using System.Runtime.Serialization;
    using System.Runtime.Serialization.Formatters.Binary;

    /// <summary>
    /// Classe pour la sérialisation et la désérialisation
    /// </summary>
    [Serializable]
    public class Serializer
    {
        #region Fields

        /// <summary>
        /// Path of the serialized file
        /// </summary>
        protected string path = Environment.CurrentDirectory;

        #endregion Fields

        #region Constructors

        /// <summary>
        /// Constructor
        /// </summary>
        public Serializer()
        {
        }

        /// <summary>
        /// Constructor
        /// </summary>
        /// <param name="path">Donne le path du du fichier dans lequel on sérialise</param>
        public Serializer(string path)
        {
            this.path = path;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Deserialize the file indacated with _FilePath
        /// </summary>
        /// <param name="filePath">Path of the file to deserialize</param>
        /// <returns>Deserialized object</returns>
        /// <exception cref="SerializationException">Pour une erreur dans la sérialisation ou la désérialisation</exception>
        /// <exception cref="ArgumentNullException">Le FileStream pour la désérialisation </exception>
        /// <exception cref="ArgumentNullException">Le fichier à sérialiser n'est pas trouvé</exception>
        public static object Deserialize(string filePath)
        {
            BinaryFormatter formatter = new BinaryFormatter();

            using (FileStream stream = new FileStream(filePath, FileMode.Open, FileAccess.Read))
            {
                return formatter.Deserialize(stream);
            }
        }

        /// <summary>
        /// Serialize the object indicated in 
        /// _FilePath
        /// </summary>
        /// <param name="filePath">Path within the serialization will save</param>
        /// <param name="toSerialize">Object to serialize</param>
        /// <exception cref="SerializationException">Pour une erreur dans la sérialisation ou la désérialisation</exception>
        /// <exception cref="ArgumentNullException">Le FileStream pour la désérialisation </exception>
        public static void Serialize(object toSerialize, string filePath)
        {
            BinaryFormatter bf = new BinaryFormatter();
            using (FileStream fs = new FileStream(filePath, FileMode.Create, FileAccess.Write))
            {
                bf.Serialize(fs, toSerialize);
            }
        }

        /// <summary>
        /// Deserialize the file
        /// </summary>
        /// <returns>L'objet désérialisé</returns>
        /// <exception cref="SerializationException">Pour une erreur dans la sérialisation ou la désérialisation</exception>
        /// <exception cref="ArgumentNullException">Le FileStream pour la désérialisation </exception>
        public object Deserialize()
        {
            return Deserialize(this.path);
        }

        /// <summary>
        /// Serialize the object
        /// </summary>
        /// <param name="toSerialize">Object to serialize</param>
        /// <exception cref="SerializationException">Pour une erreur dans la sérialisation ou la désérialisation</exception>
        /// <exception cref="ArgumentNullException">Le FileStream pour la désérialisation </exception>
        public void Serialize(object toSerialize)
        {
            Serialize(toSerialize, this.path);
        }

        #endregion Methods
    }
}